@@ -23,7 +23,7 @@ mentions_regexp: Pattern = re_compile(r"^(?:(?:https?://)?(?:www.)?furaffinity.n
 watchlist_next_regexp: Pattern = re_compile(r"/watchlist/(by|to)/[^/]+/\d+")
 
 
-def assertion_exception(err: Exception):
+def assertion_exception(err: BaseException):
     raise err
 
 
@@ -233,7 +233,6 @@ def parse_submission_page(sub_page: BeautifulSoup) -> dict[str, Any]:
     assert tag_description is not None, assertion_exception(ParsingError("Missing description tag"))
     assert tag_folder is not None, assertion_exception(ParsingError("Missing folder tag"))
     assert tag_file_url is not None, assertion_exception(ParsingError("Missing file URL tag"))
-    assert tag_thumbnail_url is not None, assertion_exception(ParsingError("Missing thumbnail URL tag"))
     assert tag_prev is not None, assertion_exception(ParsingError("Missing prev tag"))
     assert tag_next is not None, assertion_exception(ParsingError("Missing next tag"))
 
@@ -406,8 +405,9 @@ def parse_search_submissions(search_page: BeautifulSoup) -> dict[str, Any]:
 
     for div in tag_stats.select(""):
         div.decompose()
-    a, b, tot = map(int,
-                    s.groups() if (s := search(r"(\d+)[^\d]*(\d+)[^\d]*(\d+)", tag_stats.text.strip())) else (0, 0, 0))
+    a, b, tot = 0, 0, 0
+    if s := search(r"(\d+)[^\d]*(\d+)[^\d]*(\d+)", tag_stats.text.strip()):
+        a, b, tot = map(int, s.groups())
     figures: list[Tag] = search_page.select("figure[id^='sid-']")
 
     return {
